/*=========================================================================

  Program:   Visualization Toolkit
  Module:    $RCSfile: vtkXMLImageDataWriter.h,v $
  Language:  C++
  Date:      $Date: 2002/10/16 18:23:06 $
  Version:   $Revision: 1.1 $

  Copyright (c) 1993-2002 Ken Martin, Will Schroeder, Bill Lorensen 
  All rights reserved.
  See Copyright.txt or http://www.kitware.com/Copyright.htm for details.

     This software is distributed WITHOUT ANY WARRANTY; without even 
     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
     PURPOSE.  See the above copyright notice for more information.

=========================================================================*/
// .NAME vtkXMLImageDataWriter - Write VTK XML ImageData files.
// .SECTION Description
// vtkXMLImageDataWriter writes the VTK XML ImageData file format.
// One image data input can be written into one file in any number of
// streamed pieces.  The standard extension for this writer's file
// format is "vti".  This writer is also used to write a single piece
// of the parallel file format.

// .SECTION See Also
// vtkXMLPImageDataWriter

#ifndef __vtkXMLImageDataWriter_h
#define __vtkXMLImageDataWriter_h

#include "vtkXMLStructuredDataWriter.h"

class vtkImageData;

class VTK_IO_EXPORT vtkXMLImageDataWriter : public vtkXMLStructuredDataWriter
{
public:
  static vtkXMLImageDataWriter* New();
  vtkTypeRevisionMacro(vtkXMLImageDataWriter,vtkXMLStructuredDataWriter);
  void PrintSelf(ostream& os, vtkIndent indent);
  
  // Description:
  // Get/Set the writer's input.
  void SetInput(vtkImageData* input);
  vtkImageData* GetInput();
  
  // Description:
  // Get the default file extension for files written by this writer.
  const char* GetDefaultFileExtension();
  
protected:
  vtkXMLImageDataWriter();
  ~vtkXMLImageDataWriter();  
  
  void WritePrimaryElementAttributes();
  void GetInputExtent(int* extent);
  const char* GetDataSetName();
  
private:
  vtkXMLImageDataWriter(const vtkXMLImageDataWriter&);  // Not implemented.
  void operator=(const vtkXMLImageDataWriter&);  // Not implemented.
};

#endif
